+++
title = "5G IoT and the Future of Vehicle"
date = "2021-10-07T13:39:46+02:00"
tags = ["5G"]
categories = ["5G"]
banner = "https://i.imgur.com/sYF31pa.jpg"
+++

5G technology in automotive applications is on a rising trajectory today, with the advance of in-vehicle technologies, IoT innovations and the deployment of high-speed networks. There are some critical reasons for the development of these technologies and why the 5G car may be coming soon.   
  
The research might surprise you. How often do vehicle-related problems such as flat tires, steering failures or brake failures cause traffic and highway accidents? According to [research by U.S. DOT](http://www.its.dot.gov/pilots/pilots_nycdot.htm) (United States Department of Transportation), about 94% of all car crashes are caused by human error. Just 2% of accidents happen as the result of mechanical failure. Breaking down the data further, we find that one in four deaths can be attributed to speeding. The statistics are startling, indicating that a quarter of all driving-related fatalities and most traffic accidents are entirely preventable. Connected vehicles will therefore be a game changer for traffic safety.

Preventable accidents are the bad news. The good news is that we’re finally in a position to do something about it. The deployment of 5G cellular networks and other new technologies are promising to make self-driving cars a reality, and it’s happening faster than most people think. In this article we’ll look at how cities are adapting to enable connected vehicle technoloyg and autonomous driving, what the technology looks like and when we might see the rollout of the first self-driving cars. Let’s explore the future of 5G, IoT and automotive applications.  
 

Connected vs. Autonomous Vehicles: How Are They Different?
----------------------------------------------------------

t’s important to distinguish between a connected vehicle and an autonomous vehicle. A connected vehicle is one that can receive information from an outside source and/or connect with a consumer’s cellphone. Connected vehicles are already common today. For example, a car’s navigation system is connected to the GPS network. In the event of traffic or other disruptions on the road, the navigation system can plan a new route to avoid these obstacles.  
  
The next phase of connected vehicle will be advances in [V2X](https://en.wikipedia.org/wiki/Vehicle-to-everything), where X may be a pedestrian or a traffic management system in an intersection. Also known as vehicle-to-everything, V2X is the ultimate connected vehicle advance that will support automated braking of vehicles to prevent traffic accidents.   
  
[OnStar](https://www.onstar.com/us/en/support/coverage/) is another good example of a connected vehicle. In the event of an emergency, the driver can connect to a help center which can send out a tow truck or dispatch emergency services. In terms of cellphone connection, many car manufacturers already allow drivers to sync their cellphone to the car in order to use apps, play music or enable voice recognition.  
  
While OnStar and GPS are helpful services, they rely on technologies that are decades old. Even connecting a smart phone to a car’s dashboard isn’t that exciting in the grand scheme of things. The next generation of connected vehicles are going to do so much more. 5G cars will connect to 5G networks, which will not only enable ultra-fast, low-latency communications, it will also allow them to communicate with each other. For example, two 5G connected cars coming to a stop sign can agree in advance who will go through first, solving the problem that under current technology, self-driving cars tend to perform poorly at [stop signs](https://www.bloomberg.com/opinion/articles/2018-02-02/what-if-self-driving-cars-can-t-see-stop-signs).  
  
As we can see, a connected vehicle is not necessarily an autonomous vehicle. Connected vehicle technology refers to V2X advances. An autonomous vehicle is the next step, where the car does the driving, and it will ultimately rely on the integration of 5G technology in automotive systems. Some of the very first self-driving cars were not connected vehicles. They relied on radar and planned routes to navigate the roads. However, going forward most self-driving cars will be connected as there is a myriad of benefits for a relatively small cost.

We see a continuing trend to integrate car functions and related electronic control units (ECUs) into central domain controllers, with premium OEMs leading the technological push toward more [integrated and connected infotainment systems](https://www.mckinsey.com/industries/automotive-and-assembly/our-insights/setting-the-framework-for-car-connectivity-and-user-experience). Moreover, the number of applications has increased significantly as the industry moves toward a service-oriented architecture with interdependent services.

We have also noted a significant spike in the number of in-vehicle sensors. The next two to three vehicle generations will feature sensors with similar functionalities to ensure functional safety through redundancy. In the long term, however, some OEMs might opt for more intelligent sensor solutions to reduce the total number of sensors and costs. Some sensors will also become more intelligent as computing power migrates from ECUs. In the future, such sensors can preprocess data for simple calculations, trigger actuators directly, and inform ECUs retrospectively about their actions.

Most cars already allow customers and OEMs to monitor, and to some extent, interact, with their vehicles. As we move toward [an increasingly autonomous future](https://www.mckinsey.com/industries/automotive-and-assembly/our-insights/autonomous-driving-disruption-technology-use-cases-and-opportunities), many use cases will rely on this connectivity and thus increase the need for wireless capacity and reliability. What’s more, cars are likely to communicate with one another and the surrounding infrastructure, for example, to warn others about traffic incidents or poor road conditions. While OEMs are designing their autonomous vehicles to work without constant connectivity, there will be situations in the short-to midterm where remote, manual operations are required. For example, we already see some commercial vehicles capable of traveling long distances without a driver—trips that include remote operations directing the last mile to their destinations. Remote control requires ubiquitous and reliable networks in city areas with high bandwidth to transmit high-definition video, with low latency to enable smooth control. Overall, current communication infrastructure is not reliable enough for mission-critical applications. For instance, networks and direct communication systems lack the capacity to manage data traffic from fleets of autonomous cars communicating with one another in real time in dense urban environments or along crowded highways.

Moreover, Intel has estimated that a driverless car will generate more than four terabytes of data per day. While most of that will be processed in the car, there can be significant value created through sharing these data with other cars, the surrounding infrastructure, and the mobility ecosystem. The explosion of data transmission drives the need for higher speed and bandwidth, and, in turn, the penetration of antennas in cars (Exhibit 3).