+++
title= "What is NFT"
date = "2021-08-12T00:04:55+08:00"
tags = ["NFT"]
type = "blog"
categories = ["NFT"]
banner = "https://nai500.com/wp-content/uploads/2021/03/Non-fungible-tokens-NFTs-1.png"
+++

## What You Need To Know About NFTs

Non-fungible tokens (NFTs) seem to have exploded out of the ether this year. From art and music to tacos and toilet paper, these digital assets are selling like 17th-century [exotic Dutch tulips](https://www.history.com/news/tulip-mania-financial-crash-holland)—some for millions of dollars.

But are NFTs worth the money—or the hype? Some experts say they’re a bubble poised to pop, like the dotcom craze or Beanie Babies. Others believe NFTs are here to stay, and that they will change investing forever.

What Is an NFT?
---------------

An NFT is a digital asset that represents real-world objects like art, music, in-game items and videos. They are bought and sold online, frequently with [cryptocurrency](https://www.forbes.com/advisor/investing/what-is-cryptocurrency/), and they are generally encoded with the same underlying software as many cryptos.

Although they’ve been around since 2014, NFTs are gaining notoriety now because they are becoming an increasingly popular way to buy and sell digital artwork. A staggering [$174 million](https://www.coindesk.com/what-are-nfts) has been spent on NFTs since November 2017.

NFTs are also generally one of a kind, or at least one of a very limited run, and have unique identifying codes. “Essentially, NFTs create digital scarcity,” says Arry Yu, chair of the Washington Technology Industry Association Cascadia Blockchain Council and managing director of Yellow Umbrella Ventures.

This stands in stark contrast to most digital creations, which are almost always infinite in supply. Hypothetically, cutting off the supply should raise the value of a given asset, assuming it’s in demand.

But many NFTs, at least in these early days, have been digital creations that already exist in some form elsewhere, like iconic video clips from NBA games or securitized versions of digital art that’s already floating around on Instagram.

For instance, famous digital artist Mike Winklemann, better known as “Beeple” crafted a composite of 5,000 daily drawings to create perhaps the most famous NFT of the moment, “EVERYDAYS: The First 5000 Days,” which sold at Christie’s for a [record-breaking $69.3 million](https://decrypt.co/60971/beeples-nft-artwork-sells-for-60-3-million-in-christies-auction).

Anyone can view the individual images—or even the entire collage of images online for free. So why are people willing to spend millions on something they could easily screenshot or download?

Because an NFT allows the buyer to own the original item. Not only that, it contains built-in authentication, which serves as proof of ownership. Collectors value those “digital bragging rights” almost more than the item itself.

How Is an NFT Different from Cryptocurrency?
--------------------------------------------

NFT stands for non-fungible token. It’s generally built using the same kind of programming as cryptocurrency, like [Bitcoin](https://www.forbes.com/advisor/investing/what-is-bitcoin/) or [Ethereum](https://www.forbes.com/advisor/investing/what-is-ethereum-ether/), but that’s where the similarity ends.

Physical money and cryptocurrencies are “fungible,” meaning they can be traded or exchanged for one another. They’re also equal in value—one dollar is always worth another dollar; one Bitcoin is always equal to another Bitcoin. Crypto’s fungibility makes it a trusted means of conducting transactions on the blockchain.

NFTs are different. Each has a digital signature that makes it impossible for NFTs to be exchanged for or equal to one another (hence, non-fungible). One NBA Top Shot clip, for example, is not equal to EVERYDAYS simply because they’re both NFTs. (One NBA Top Shot clip isn’t even necessarily equal to another NBA Top Shot clip, for that matter.)

How Does an NFT Work?
---------------------

NFTs exist on a blockchain, which is a distributed public ledger that records transactions. You’re probably most familiar with blockchain as the underlying process that makes cryptocurrencies possible.

Specifically, NFTs are typically held on the [Ethereum](https://www.forbes.com/advisor/investing/what-is-ethereum-ether/) blockchain, although other blockchains support them as well.

An NFT is created, or “minted” from digital objects that represent both tangible and intangible items, including:

**•** Art

**•** GIFs

**•** Videos and sports highlights

**•** Collectibles

**•** Virtual avatars and video game skins

**•** Designer sneakers

**•** Music

Even tweets count. Twitter co-founder Jack Dorsey sold his first ever tweet as an NFT for [more than $2.9 million](https://www.cnbc.com/2021/03/22/jack-dorsey-sells-his-first-tweet-ever-as-an-nft-for-over-2point9-million.html).

Essentially, NFTs are like physical collector’s items, only digital. So instead of getting an actual oil painting to hang on the wall, the buyer gets a digital file instead.

They also get exclusive ownership rights. That’s right: NFTs can have only one owner at a time. NFTs’ unique data makes it easy to verify their ownership and transfer tokens between owners. The owner or creator can also store specific information inside them. For instance, artists can sign their artwork by including their signature in an NFT’s metadata.

What Are NFTs Used For?
-----------------------

Blockchain technology and NFTs afford artists and content creators a unique opportunity to monetize their wares. For example, artists no longer have to rely on galleries or auction houses to sell their art. Instead, the artist can sell it directly to the consumer as an NFT, which also lets them keep more of the profits. In addition, artists can program in royalties so they’ll receive a percentage of sales whenever their art is sold to a new owner. This is an attractive feature as artists generally do not receive future proceeds after their art is first sold.

Art isn’t the only way to make money with NFTs. Brands like Charmin and Taco Bell have auctioned off themed NFT art to raise funds for charity. Charmin dubbed its offering “NFTP” (non-fungible toilet paper), and Taco Bell’s NFT art sold out in minutes, with the highest bids coming in at 1.5 wrapped ether (WETH)—equal to $3,723.83 at time of writing.

Nyan Cat, a 2011-era GIF of a cat with a pop-tart body, sold for nearly [$600,000 in February](https://www.nytimes.com/2021/02/22/business/nft-nba-top-shot-crypto.html). And NBA Top Shot generated more than [$500 million in sales](https://www.usatoday.com/story/sports/nba/2021/03/30/nba-top-shot-dapper-labs-valuation-funding-round/7058307002/) as of late March. A single LeBron James highlight NFT fetched more than $200,000.

Even celebrities like Snoop Dogg and Lindsay Lohan are jumping on the NFT bandwagon, releasing unique memories, artwork and moments as securitized NFTs.

How to Buy NFTs
---------------

If you’re keen to start your own NFT collection, you’ll need to acquire some key items:

First, you’ll need to get a digital wallet that allows you to store NFTs and cryptocurrencies. You’ll likely need to purchase some [cryptocurrency](https://www.forbes.com/advisor/investing/best-crypto-exchanges/ "cryptocurrency"), like Ether, depending on what currencies your NFT provider accepts. You can buy crypto using a credit card on platforms like Coinbase, Kraken, eToro and even PayPal and Robinhood now. You’ll then be able to move it from the exchange to your wallet of choice.

You’ll want to keep fees in mind as you research options. Most exchanges charge at least a percentage of your transaction when you buy crypto.

### Popular NFT Marketplaces

Once you’ve got your wallet set up and funded, there’s no shortage of NFT sites to shop. Currently, the largest NFT marketplaces are:

**•** [**OpenSea.io**](https://opensea.io/): This peer-to-peer platform bills itself a purveyor of “rare digital items and collectibles.” To get started, all you need to do is create an account to browse NFT collections. You can also sort pieces by sales volume to discover new artists.

**•** [**Rarible**](https://rarible.com/): Similar to OpenSea, Rarible is a democratic, open marketplace that allows artists and creators to issue and sell NFTs. RARI tokens issued on the platform enable holders to weigh in on features like fees and community rules.

**•** [**Foundation**](https://foundation.app/): Here, artists must receive “upvotes” or an invitation from fellow creators to post their art. The community’s exclusivity and cost of entry—artists must also purchase “gas” to mint NFTs—means it may boast higher-caliber artwork. For instance, Nyan Cat creator Chris Torres sold the NFT on the Foundation platform. It may also mean higher prices — not necessarily a bad thing for artists and collectors seeking to capitalize, assuming the demand for NFTs remains at current levels, or even increases over time.

Although these platforms and others are host to thousands of NFT creators and collectors, be sure you do your research carefully before buying. Some artists have fallen victim to impersonators who have listed and sold their work without their permission.

In addition, the verification processes for creators and NFT listings aren’t consistent across platforms — some are more stringent than others. OpenSea and Rarible, for example, do not require owner verification for NFT listings. Buyer protections appear to be sparse at best, so when shopping for NFTs, it may be best to keep the old adage “caveat emptor” (let the buyer beware) in mind.

![how to plan video](https://thumbor.forbes.com/thumbor/fit-in/900x510/https://www.forbes.com/advisor/wp-content/uploads/2021/04/NFT.jpeg.jpg)