+++
title = "What is Hybrid AI?"
date = "2021-07-27T23:01:23+08:00"
type = "blog"
banner = "https://i.imgur.com/jdQb3ZH.jpg"
+++

 ## What is Hybrid AI?

 ![img](https://analyticsindiamag.com/wp-content/uploads/2021/07/aim-illustration3-1-1.jpg)] 

As the research community makes progress in artificial intelligence and deep learning, scientists are increasingly feeling the need to move towards hybrid artificial intelligence. Hybrid AI is touted to solve fundamental problems that deep learning faces today.

Hybrid AI brings together the best aspects of neural networks and symbolic AI. Combining huge data sets (visual and audio, textual, emails, chat logs, etc.) allows neural networks to extract patterns. Then, rule-based AI systems can manipulate the retrieved information by using algorithms to manipulate symbols.

Researchers are working to develop hybrid AI systems that can figure out simple abstract relations between objects and the reason behind them as effortlessly as a human brain.

What is symbolic AI?

During the 1960s and 1970s, new technological advances were met with researchers’ increasing desire to understand how machines and nature interact. Researchers believed that using symbolic approaches would inevitably produce an artificially intelligent machine, which was seen as their discipline’s long-term goal.

The “good old-fashioned artificial intelligence” or “GOFAI” was coined by John Haugeland in his 1985 book ‘Artificial Intelligence: The Very Idea‘ that explored artificial intelligence’s ethical and philosophical implications. Since the initial efforts to build thinking computers in the 1950s, research and development in the AI field have followed two parallel approaches: symbolic AI and connectionist AI.

Symbolic AI (also known as Classical AI) is an area of artificial intelligence research that focuses on attempting to express human knowledge clearly in a declarative form, that is, facts and rules. From the mid-1950s until the late 1980s, there was significant use of symbolic artificial intelligence. On the other hand, in recent years, a connectionist approach such as machine learning with deep neural networks has come to the forefront.

Combining symbolic AI and neural networks

There has been a shift from the symbolic approach in the past few years due to its technical limits.

According to David Cox, IBM Director at MIT-IBM Watson AI Lab, deep learning and neural networks excel at the “messiness of the world,” but symbolic AI does not. Neural networks meticulously study and compare a large number of annotated instances to discover significant relationships and create corresponding mathematical models.

Several prominent IT businesses and academic labs have put significant effort into the use of deep learning. Neural networks and deep learning excel at tasks where symbolic AI fails. As a result, it’s being used to tackle complex challenges today. For example, deep learning has made significant contributions to the computer vision revolution with use cases in facial recognition and tuberculosis detection. Language-related activities have also benefited from deep learning breakthroughs.

There are, however, certain limits to deep learning and neural networks. One argument is that the availability of large volumes of data depends on it. In addition, neural networks are also vulnerable to hostile instances, often known as adversarial data, which can manipulate an AI model’s behaviour in unpredictable and harmful ways.

However, when combined with each other, symbolic AI and neural networks can form a good base for developing hybrid AI systems.

Future of hybrid AI

The hybrid AI model utilises the neural network’s ability to process and evaluate unstructured data while also using symbolic AI techniques. Connectivist viewpoints argue that techniques based on neural networks will eventually provide sophisticated and broadly applicable AI. In 2019, International Conference on Learning Representations (ICLR) featured a paper in which the researchers combined neural networks with rule-based artificial intelligence to create an AI model. This approach has been called the “Neuro-Symbolic Concept Learner” (NCSL); it claims to overcome the difficulties AI faces and to be superior to the sum of its parts. NCSL, a hybrid system of AI developed by researchers at MIT and IBM tackles visual question answering (VQA) problems; the NSCL uses neural networks in conjunction with neural networks with remarkable accuracy. The researchers demonstrated that NCSL was able to handle the VQA dataset CLEVR. Even more important, the hybrid AI model could make outstanding achievements with less training data and overcome two long-standing deep learning challenges.

Even Google search engine is a complex, all-in-one AI system made up of cutting-edge deep learning tools such as Transformers and advanced symbol manipulation tools like the knowledge graph.

Join Our Telegram Group. Be part of an engaging online community. Join Here.

Subscribe to our Newsletter

Get the latest updates and relevant offers by sharing your email.

 ## 電動化を推進する英高級車メーカーのベントレーが新型車「フライングスパー・ハイブリッド」を発表

 ![img](https://jp.techcrunch.com/wp-content/uploads/2021/07/Flying-Spur-Hybrid_Courtesy-of-Bentley-Motors5.jpg?w=1024)] 



 ## A Hybrid AI Approach to Optimizing Oil Field Planning

 ![img](https://2s7gjr373w3x22jf92z99mgm5w-wpengine.netdna-ssl.com/wp-content/uploads/2021/07/oil_pumps_shutterstock_pan-demin.jpg)] 

What’s the best way to arrange wells in an oil or gas field? It’s a simple enough question, but the answer can be very complex. Now a Cal Tech/JPL spinoff is developing a new approach that blends traditional HPC simulation with deep reinforcement learning running on GPUs to optimize energy extraction.

The well placement game is a familiar one to oil and gas companies. For years, they have been using simulators running atop HPC systems to model underground reservoirs. Atop that model, they use some sort of optimizer to drive iterations of the model, with the goal of coming up with the optimal number, type, and placement of wells for a given field.

The possible combinations of number, type, and placement quickly becomes a challenging math problem, according to Beyond Limits’ Chief Technology Officer for Industrial AI Shahram Farhadi. Even with a “fairly simple” model with a million grids and five wells (one injector well and four producer wells) the number of possible moves is on the order of 10 to the 20th power, he says. By comparison, there are 5 million possible combinations of chess pieces in five moves, and 10 to the 12th possible combinations five moves into Go.

“The optimization problem is combinatoric, and it explodes really fast,” Farhadi says. “In that sense, you have an optimization that is intractable, if your only tool is brute search.”

The optimizers that energy companies currently rely on include things like genetic algorithms and particle swarm algorithms, Farhadi says. “They are all well and good,” he says, “but they are optimizers in the simplest sense.”

At Beyond Limits, Farhadi has spearheaded a new approach to optimizer development that leverages some of the latest breakthroughs in reinforcement learning and deep convolutional neural networks.

Deep learning approaches are able to work with, and learn from, much larger pools of data than traditional machine learning algorithms. The radar tomography data that is fed into traditional physics simulators is one piece of the puzzle in the well placemeng game. But in this case, the results from each successive run of the simulator are really what the deep learning appraoch builds upon. By pairing its new AI-based field planning agent with a traditional physics simuilator, Beyond Limits is pushing the state-of-the-art in oil well field planning.

According to Farhadi, the new field planning agent is able to learn from subsequent iterations of the simulator. “Winning” is defined as a high net present value (NPV) score, which is basically the predicted overall oil or gas recovery minus the costs. The HPC model represents the physics of multi-phase flow and its unique patterns, which informs well spacing (if you place wells too closely, they will draw from each other).

“The reinforcement learning tries to learn by combining this representation of the states and what happened,” Farhadi tells Datanami.” says. “Think of a sequence of actions, and then the reward of, did we lose or win. And then that reward is fed back through the system so that the system learns to only take actions that are rewarding.”

The approach essentially codifies advances in expert systems (this IP was licensed from CalTech/JPL) into a deep learning model that’s composed of perceivers and reasoners. The perceivers will create labels from the pixels, and then the reasoner will make sense of the labels to make a determination about the world, Farhadi says.

The trick that Farhadi and his team brought to bear was how to map the three-dimensional radar tomography data into winning and losing arguments that the deep learning model could act upon. The system essentially is remembering what worked in previous iterations, which are written into the layers of the neural network, and incorporating that knowledge for each subsequent round until the improvements stop accruing and it converges at the optimal answer.

“The reinforcement learning paradigm [works]… in a way that you kind of try to memorize the states that are image-like, in this case 3D images,” Farhadi says. “It’s fairly new. So we are actually the first to set it out. And we had to modify the algorithms quite a bit to enable them to, let’s say, go from learning a game to learning this game. The NPV is more on the continuum space. It’s not only to win.”

Once Farhadi and his crew developed the new field planning agent, the next step was getting it to scale to the limits that oil companies will need. Beyond Limits, which was founded in Glendale, California in 2014, benchmarked the new model on three different setups, including a 20-core CPU system, a 96-core CPU system, and a single core Nvidia A100 GPU system.

Not surprisingly, the GPU-based system showed the highest performance on the benchmark tests, both in terms of iteration time and higher NPV (see figure). The company has already partnered with one oil company, which realized $50 million in production value from the project, the company says.

The hybrid AI approach delivered a 184% peak increase in processing speed compared to standard operations, Beyond Limits says. The field planning agent delivered a 15% improvement in the number of simulations run compared to other optimization techniques. What’s more, the environmental impact was minimized, as the company was able to reduce the number of wells to water injector and four oil producers, compared to eight to 12 injector wells and four producers in the standard configuration, the company says.

“This decreases the amount of drilling that is needed,” Fahradi says. “But also I think it’s important to abstract this way a little bit and think of the simulation as any other industrial simulator. We [foresee] similar thing with power plants and with refineries.”

Related Items:

Digital Twins and AI Keep Industry Flexible During COVID-19

Texas A&M Reinforcement Learning Algorithm Automates Oil and Gas Reserve Forecasting

Accelerate Exploration and Discovery with Remote Visualization

 ## TU Dresden, University of Manchester and GlobalFoundries Announce SpiNNaker2, a Breakthrough in AI Cloud Systems, Bringing Real-Time AI with below Millisecond Latency and high Energy Efficiency to Clo

 ![img](https://www.design-reuse.com/news_img2/homepage50366/aib.jpg)] 

TU Dresden, University of Manchester and GlobalFoundries Announce SpiNNaker2, a Breakthrough in AI Cloud Systems, Bringing Real-Time AI with below Millisecond Latency and high Energy Efficiency to Cloud Scale

Dresden − July 27, 2021 − Technische Universität Dresden, the University of Manchester, Racyics GmbH, and GlobalFoundries (GF), the world’s leading specialty foundry, today announced the tapeout of the SpiNNaker2 chip, a new artificial intelligence chip inspired by the human brain. Based on the SpiNNaker infrastructure developed by University Manchester, the hybrid AI architecture created at TU Dresden, the adaptive body bias IP platform ABX® by Racyics, and utilizing GF’s 22FDX® solution, SpiNNaker2 is a realtime neuromorphic AI processor with unparalleled efficiency and below millisecond latency for event-based systems. SpiNNaker2 is designed to scale up to a 70.000 chip cloud system while maintaining strict real time operation. SpiNNaker2 is a key enabler for real time AI at massive data rates. It will have a disruptive impact on AI applications such as smart cities, 5G, tactile internet, autonomous driving, which are beyond current hardware because of their triple demands on low latency, high throughput, and high energy efficiency. The full 10 Mio core SpiNNaker2 machine, called ‘SpiNNcloud’, will be deployed at Technische Universität Dresden for research purposes. In parallel, the startup ‘SpiNNcloud Systems GmbH’ will make SpiNNaker2 commercially available.

AI is having an increasingly large impact on our daily lives. However, current AI hardware and algorithms are still only partially inspired by the major blueprint for AI, i.e. the human brain. In particular, even the best AI hardware is still far away from the 20W power consumption, the low latency and the unprecedented large scale, high-throughput processing offered by the human brain. SpiNNaker2 is a multi-processor system for event based real-time processing of both classic AI and upcoming sparse, event-based compute paradigms inspired by the parsimonious, on-demand processing nature of the brain. It has been developed within the European Union flagship project “Human Brain Project” (https://www.humanbrainproject.eu). SpiNNaker2 features a patented event-based compute architecture with power management and custom AI hardware acceleration. Its backbone is a tailored, light weight communication infrastructure that can be scaled from edge devices up to large scale server/cloud applications, while not suffering from the inherent slow-down that usually results from scaling computing up to cloud dimensions.

As Prof. Steve Furber (University of Manchester) states: “There is still a great deal to learn from biology if we are to realize the full potential of AI in the future. SpiNNaker2 has been designed to bridge the gulf between realistic brain models and AI so that each may increasingly be informed by the other”.

The SpiNNaker2 Chip is targeted to build up a 70.000 chip, 10 Mio Arm core ‘SpiNNcloud’ at Technische Universität Dresden, which will be used with local initiatives such the excellency cluster CETI, national and international partners to explore applications that range from autonomous driving, handling of the data of a smart city in real time, tactile internet applications, up to biomedical processing.

“Our holistic sparsity-optimized system design, combined with a unique hybrid AI framework enables real-time AI at an unprecedented large-scale. We will do world-class research on novel machine learning via the SpiNNaker2 machine at TU Dresden, but we are proud to also offer this unique AI commercially through our startup SpiNNcloud Systems (www.spinncloud.com)”, states Prof. Christian Mayr (Technische Universität Dresden).

SpiNNaker2 was realized in the 22FDX Ecosystem using the adaptive body biasing IP platform (ABX®) of Racyics GmbH to leverage the full potential of 22FDX. It enables SpiNNaker2 to robustly operate at the minimum energy point of the processing elements at 0.50V with additional support of dynamic voltage and frequency scaling for instantaneous high performance on demand. Thus, SpiNNaker2 leverages the advanced power saving features of 22FDX, the flagship technology offered by GF Dresden. The complete chip design was done using makeChip (www.makechip.design) a turnkey hosted design environment for 22FDX offered by Racyics. This approach was key for the academic group to close the so-called lab-to-fab gap and to realize a very complex System-on-Chip for volume production successfully.

22FDX®, GF’s unique 22nm FD-SOI transistor technology, with its world class low standby power and optimized transistor performance at low cost, proves to be an ideal basis at the forefront of true artificial intelligence. The 22FDX based SpiNNaker2 chip shows the synergy of European world-class AI research meeting European world-class chip technology, beginning to close the huge gap between pure computing power AI and true brain-like AI.

“As the world’s leading specialty foundry, GF enables world-class teams to achieve commercial breakthroughs. SpiNNaker2 is tangible evidence of the outstanding performance at extremely low power achieved by combining the latest advancements in brain-like artificial intelligence and our high-performance 22FDX technology”, says Dr. Manfred Horstmann, head of GlobalFoundries Dresden.







 ## Announcing IBM z/OS V2.5, Next-Gen Operating System Designed for Hybrid Cloud and AI

 ![img](https://s.yimg.com/uu/api/res/1.2/ZO_gsHEeBHuDl00SB4ThFA--~B/aD0yMDk7dz00MDA7YXBwaWQ9eXRhY2h5b24-/https://media.zenfs.com/en/prnewswire.com/43eb5753c7bd118025a0bef1268e2a90)] 

V2.5 Brings AI Capabilities to IBM Z, Strengthens Security, Introduces New Capabilities for Application Modernization

ARMONK, N.Y., July 27, 2021 /PRNewswire/ -- IBM (NYSE: IBM) today announced IBM z/OS V2.5, the next-generation operating system (OS) for IBM Z, designed to accelerate client adoption of hybrid cloud and AI and drive application modernization projects.

IBM Corporation logo. (PRNewsfoto/IBM)

According to an IBM Institute for Business Value study "Application modernization on the mainframe" released today, 71% of executives surveyed say mainframe-based applications are central to their business strategy; and in three years, the percentage of organizations leveraging mainframe assets in a hybrid cloud environment is expected to increase by more than 2x.

IBM z/OS V2.5 helps drive value for our clients by delivering new capabilities across AI enablement, application modernization, resiliency, enhanced security and an improved developer experience.

AI capabilities on IBM Z

According to the "Global AI Adoption Index 2021," conducted by Morning Consult commissioned by IBM, 87% of global IT professionals surveyed report it is very or somewhat important to their company that they can build and run their AI projects wherever the data resides[1]. With z/OS V2.5, IBM is introducing new high performance AI capabilities that are tightly integrated with z/OS workloads, designed to give clients business insights for more informed decision making.

"IBM is all-in on hybrid cloud and AI, and we are deeply focused on delivering new innovations like AI and new security capabilities on IBM Z to help our clients move forward, more quickly with their modernization journeys," said Ross Mauri, GM, IBM Z. "For our clients, IBM z/OS V2.5 brings new security and resiliency capabilities to the platform, and enables clients to infuse AI in real-time into every business transaction – imperatives that became more urgent during the pandemic."

Story continues

Enhanced security to make client data future ready

Amid recent threats like SolarWinds and the Colonial Pipeline ransomware attack against critical infrastructure, there is a continued need for clients to further strengthen their overall cyber security and resiliency posture. IBM z/OS V2.5 is helping to address these challenges by unveiling a broad spectrum of enhancements across authentication, authorization, logging, system integrity, system and data availability, encryption for data in flight and at rest, and overall data privacy including:

Expanding pervasive encryption to new types of data sets: sequential basic format and large format SMS-managed data sets are now included, providing users with the capability to encrypt data without application changes and to simplify compliance

Anomaly Mitigation capabilities that leverage Predictive Failure Analysis (PFA), Runtime Diagnostics, Workload Manager (WLM), and JES2 to help further detect anomalous behavior in near real-time, letting clients proactively address potential problems

A secured, scalable environment for hybrid cloud

As clients accelerate their journey to hybrid cloud, having a secured, scalable environment is critical for the underlying transformation process. IBM z/OS V2.5 introduces new capabilities that support application modernization and provide a cloud native experience on z/OS:

New Java/COBOL Interoperability that extends existing application programming models with support for parallel 31-bit and 64-bit addressing, simplifying enterprise application modernization.

Enhanced performance and ease of use for z/OS Container Extensions (zCX) to integrate Linux applications and utilities into z/OS.

Additional capabilities to integrate cloud storage through transparent cloud tiering (TCT) and the Object Access Method (OAM) cloud tier support to help reduce capital and operating expenses with data transfer to hybrid cloud storage environments for simplified data archiving and data protection on IBM Z.

IBM z/OS V2.5 is expected to be faster and easier to install and upgrade, with one client trial demonstrating the ability to install z/OS more than 30% faster than compared with IBM z/OS 2.3 and 2.4.[2] With a simplified management experience supplied by streamlined and automated tasks, specialty skills may not be required. IBM z/OS V2.5 is expected to be generally available on September 30, 2021.

Statements regarding IBM's future direction and intent are subject to change or withdrawal without notice and represent goals and objectives only.

About IBM

IBM is a leading global hybrid cloud and AI, and business services provider, helping clients in more than 175 countries capitalize on insights from their data, streamline business processes, reduce costs and gain the competitive edge in their industries. Nearly 3,000 government and corporate entities in critical infrastructure areas such as financial services, telecommunications and healthcare rely on IBM's hybrid cloud platform and Red Hat OpenShift to affect their digital transformations quickly, efficiently, and securely. IBM's breakthrough innovations in AI, quantum computing, industry-specific cloud solutions and business services deliver open and flexible options to our clients. All of this is backed by IBM's legendary commitment to trust, transparency, responsibility, inclusivity, and service.

For more information, visit www.ibm.com

Media Contact:

Elizabeth Banta

IBM Systems

Elizabeth.Banta@ibm.com

732-996-4159

1 https://filecache.mediaroom.com/mr5mr_ibmnewsroom/191468/IBM%27s%20Global%20AI%20Adoption%20Index%202021_Executive-Summary.pdf

2 According to internal client benchmarks

Cision

View original content to download multimedia:https://www.prnewswire.com/news-releases/announcing-ibm-zos-v2-5--next-gen-operating-system-designed-for-hybrid-cloud-and-ai-301341669.html

SOURCE IBM

